@@ -249,6 +249,9 @@ const Application = new Lang.Class({
                 if (actionEntry.accel)
                     this.add_accelerator(actionEntry.accel, 'app.' + actionEntry.name, null);
 
+                if (actionEntry.accels)
+                    this.set_accels_for_action('app.' + actionEntry.name, actionEntry.accels);
+
                 this.add_action(action);
             }));
     },
@@ -428,8 +431,7 @@ const Application = new Lang.Class({
             { name: 'open-current',
               callback: this._onActionOpenCurrent,
               window_mode: WindowMode.WindowMode.PREVIEW },
-            { name: 'edit-current',
-              window_mode: WindowMode.WindowMode.PREVIEW },
+            { name: 'edit-current' },
             { name: 'view-current',
               window_mode: WindowMode.WindowMode.EDIT },
             { name: 'present-current',
@@ -448,9 +450,7 @@ const Application = new Lang.Class({
               window_mode: WindowMode.WindowMode.PREVIEW },
             { name: 'find-prev', accel: '<Shift><Primary>g',
               window_mode: WindowMode.WindowMode.PREVIEW },
-            { name: 'zoom-in', accel: '<Primary>plus',
-              window_mode: WindowMode.WindowMode.PREVIEW },
-            { name: 'zoom-in', accel: '<Primary>equal',
+            { name: 'zoom-in', accels: ['<Primary>plus', '<Primary>equal'],
               window_mode: WindowMode.WindowMode.PREVIEW },
             { name: 'zoom-out', accel: '<Primary>minus',
               window_mode: WindowMode.WindowMode.PREVIEW },
@@ -530,6 +530,7 @@ const Application = new Lang.Class({
         trackerController.disconnectAll();
         selectionController.disconnectAll();
         modeController.disconnectAll();
+        this.disconnectAllJS();
 
         // reset state
         documentManager.setActiveItem(null);
