@@ -44,7 +44,7 @@ const MainToolbar = new Lang.Class({
         this.widget = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL });
         this.widget.show();
 
-        this.toolbar = new Gtk.HeaderBar();
+        this.toolbar = new Gtk.HeaderBar({ hexpand: true });
         this.toolbar.get_style_context().add_class('titlebar');
         this.widget.add(this.toolbar);
         this.toolbar.show();
