@@ -248,6 +248,18 @@ const ViewContainer = new Lang.Class({
             this._addListRenderers();
     },
 
+    getFirstDocument: function() {
+        let doc = null;
+
+        let iter = this._model.model.get_iter_first()[1];
+        if (iter) {
+            let id = this._model.model.get_value(iter, Gd.MainColumns.ID);
+            doc = Application.documentManager.getItemById(id);
+        }
+
+        return doc;
+    },
+
     _addListRenderers: function() {
         let listWidget = this.view.get_generic_view();
 
